@@ -38,7 +38,7 @@ def seas_line_plot(df, fwd=None, **kwargs):
     title = cpu.gen_title(df, **kwargs)
     legend = go.layout.Legend(font=dict(size=10))
     yaxis_title = kwargs.get('yaxis_title', None)
-    fig.update_layout(title=title, xaxis_tickformat='%b', yaxis_title=yaxis_title, legend=legend)
+    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b', yaxis_title=yaxis_title, legend=legend)
 
     return fig
 
@@ -87,7 +87,7 @@ def seas_line_subplot(rows, cols, df, fwd=None, **kwargs):
     legend = go.layout.Legend(font=dict(size=10))
     fig.update_xaxes(tickvals=pd.date_range(start=str(dates.curyear), periods=12, freq='MS'), tickformat='%b')
     title = kwargs.get('title', '')
-    fig.update_layout(title=title, xaxis_tickformat='%b', legend=legend)
+    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b', legend=legend)
     return fig
 
 
@@ -118,7 +118,7 @@ def seas_box_plot(hist, fwd=None, **kwargs):
 
     fig = go.Figure(data=data)
     title = kwargs.get('title', '')
-    fig.update_layout(title=title)
+    fig.update_layout(title=title, title_x=0.01)
 
     return fig
 
@@ -199,7 +199,7 @@ def forward_history_plot(df, title=None, **kwargs):
     fig['data'][0]['line']['width'] = 2.2  # make latest line thicker
     legend = go.layout.Legend(font=dict(size=10))
     yaxis_title = kwargs.get('yaxis_title', None)
-    fig.update_layout(title=title, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
+    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
     return fig
 
 
@@ -219,7 +219,7 @@ def bar_line_plot(df, linecol='Total', **kwargs):
     yaxis_title = kwargs.get('yaxis_title', None)
     yaxis_range = kwargs.get('yaxis_range', None)
     title = kwargs.get('title', None)
-    fig.update_layout(title=title, xaxis_title='Date', yaxis_title=yaxis_title)
+    fig.update_layout(title=title, title_x=0.01, xaxis_title='Date', yaxis_title=yaxis_title)
     if yaxis_range is not None:
         fig.update_layout(yaxis=dict(range=yaxis_range))
     return fig
@@ -248,7 +248,7 @@ def diff_plot(df, **kwargs):
         fig.add_trace(go.Bar(x=df.index, y=df[col], name=col), row=2, col=1)
 
     title = kwargs.get('title', '')
-    fig.update_layout(title_text=title)
+    fig.update_layout(title_text=title, title_x=0.01)
     return fig
 
 
@@ -280,7 +280,7 @@ def reindex_year_line_plot(df, **kwargs):
 
     legend = go.layout.Legend(font=dict(size=10))
     yaxis_title = kwargs.get('yaxis_title', None)
-    fig.update_layout(title=title, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
+    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
     # zoom into last 3 years
     fig.update_xaxes(type="date",
                      range=[dft.tail(365 * 3).index[0].strftime('%Y-%m-%d'), dft.index[-1].strftime('%Y-%m-%d')])
@@ -320,7 +320,7 @@ def reindex_year_line_subplot(rows, cols, dfs, **kwargs):
     legend = go.layout.Legend(font=dict(size=10))
     yaxis_title = kwargs.get('yaxis_title', None)
     title = kwargs.get('title', '')
-    fig.update_layout(title=title, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
+    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend)
 
     fig.update_xaxes(type="date")
 
@@ -336,5 +336,5 @@ def line_plot(df, fwd=None, **kwargs):
     title = cpu.gen_title(df, inc_change_sum=False, **kwargs)
     legend = go.layout.Legend(font=dict(size=10))
     yaxis_title = kwargs.get('yaxis_title', None)
-    fig.update_layout(title=title, yaxis_title=yaxis_title, legend=legend)
+    fig.update_layout(title=title, title_x=0.01, yaxis_title=yaxis_title, legend=legend)
     return fig
