@@ -2,33 +2,15 @@ from commodutil import dates
 from commodutil import transforms
 from commodplot import commodplotutil as cpu
 from commodplot import commodplottransform as cpt
+import plotly
 import plotly.graph_objects as go
 import pandas as pd
 import numpy as np
 
+from commodplot.commodplotutil import default_line_col, year_col_map
 
-default_line_col = 'khaki'
 hovertemplate_default = '%{y:.2f}: <i>%{text}</i>'
 
-# try to put deeper colours for recent years, lighter colours for older years
-year_col_map = {
-    -10: 'wheat',
-    -9: 'burlywood',
-    -8: 'steelblue',
-    -7: 'aquamarine',
-    -6: 'orange',
-    -5: 'yellow',
-    -4: 'saddlebrown',
-    -3: 'mediumblue',
-    -2: 'darkgreen',
-    -1: 'coral',
-    0: 'black',
-    1: 'red',
-    2: 'firebrick',
-    3: 'darkred',
-    4: 'crimson',
-}
-
 
 def get_year_line_col(year):
     """
@@ -38,6 +20,17 @@ def get_year_line_col(year):
     return year_col_map.get(delta, default_line_col)
 
 
+def get_sequence_line_col(seqno: int):
+    """
+    Given a sequence number select the colour from default plotly palette
+    Required for line plot where history and forward should be same color
+    :param seqno:
+    :return:
+    """
+    if seqno <= len(plotly.colors.qualitative.Plotly):
+        return plotly.colors.qualitative.Plotly[seqno]
+
+
 def line_visible(year, visible_line_years=None):
     """
     Determine the number of year lines to be visible in seasonal plot
@@ -46,6 +39,8 @@ def line_visible(year, visible_line_years=None):
     :return:
     """
     delta = get_year_line_delta(year)
+    if delta is None:
+        return None
     if visible_line_years:
         visible_line_years = visible_line_years * -1 # number of years to go back
     else:
@@ -55,7 +50,7 @@ def line_visible(year, visible_line_years=None):
 
 
 def get_year_line_delta(year):
-    if isinstance(year, str):
+    if isinstance(year, str) and year.isnumeric():
         year = int(year)
 
     delta = year - dates.curyear
@@ -70,26 +65,6 @@ def get_year_line_width(year):
     return 2
 
 
-def std_yr_col(df, asdict=False):
-    """
-    Given a dataframe with yearly columns, determine the line colour to use
-    """
-
-    if isinstance(df, pd.Series):
-        df = pd.DataFrame(df)
-
-    yearmap = dates.find_year(df, use_delta=True)
-    colmap = {}
-    for colname, delta in yearmap.items():
-        colmap[colname] = year_col_map.get(delta, default_line_col)
-
-    if asdict:
-        return colmap
-
-    # return array of colours to use - this can be passed into cufflift iplot method
-    return [colmap[x] for x in df]
-
-
 def clean_seas_df_for_min_max_average(seas, range):
     """
     Given a seasonalised dataframe, clean to handle missing data
@@ -386,26 +361,44 @@ def timeseries_trace_by_year(series: pd.Series, colyear:int, promptyear:int=None
                          promptyear=promptyear,
                          width=width,
                          visible=visible,
-                         color=color)
+                         color=color,
+                         legendgroup=kwargs.get('legendgroup'),
+                         showlegend=kwargs.get('showlegend'))
     return t
 
 
-def line_plot_traces(df, **kwargs):
+def line_plot_traces(df, fwd=None, **kwargs):
     """
-    Generate traces for a timeseries
+    Generate traces for a timeseries. If historic and forward values are passed,
+    then show solid lines followed by forward lines
     :param df:
     :param kwargs:
     :return:
     """
     traces = []
     colyearmap = cpu.dates.find_year(df)
+    colcount = 0
     for col in df.columns:
         colyear = colyearmap[col]
-        if colyear:
-            trace = timeseries_trace_by_year(df[col], colyear)  # , text, **kwargs)
+        if isinstance(colyear, int) or (isinstance(colyear, str) and colyear.isnumeric()):
+            trace = timeseries_trace_by_year(df[col], colyear, legendgroup=col)  # , text, **kwargs)
         else:
-            trace = timeseries_trace(df[col])  #
+            trace = timeseries_trace(df[col], legendgroup=col, color=get_sequence_line_col(colcount))  #
 
         traces.append(trace)
 
+        if fwd is not None and col in fwd.columns:
+            f = fwd[col]
+            fwdfreq = pd.infer_freq(f.index)
+            if fwdfreq in ['MS', 'ME']:
+                f = transforms.format_fwd(f, df.index[-1])  # only applies for forward curves
+            if isinstance(colyear, int) or (isinstance(colyear, str) and colyear.isnumeric()):
+                trace = timeseries_trace_by_year(f, colyear, legendgroup=col, showlegend=False,)  # , text, **kwargs)
+            else:
+                trace = timeseries_trace(f, dash='dash', legendgroup=col, showlegend=False,
+                                         color=get_sequence_line_col(colcount))
+            traces.append(trace)
+
+        colcount = colcount + 1
+
     return traces
